==> ursa_3.10.4.tar.gz: ursa/R/yyy.RogerBivand.R <==
'.DeadEnd' <- function() stop("Dead End after {rgdal}/{rgeos}/{maptools} retiring")
'.open_rgdal' <- function(...) .DeadEnd()
'.rgdal_getRasterData' <- function(...) .DeadEnd()
'.rgdal_putRasterData' <- function(...) .DeadEnd()
'.shp.read' <- function(...) .DeadEnd()
'.shp.write' <- function(...) .DeadEnd()
'.rgdal_close_Transient' <- function(...) .DeadEnd()
'.rgdal_close_ReadOnly' <- function(...) .DeadEnd()
'.read_gdal' <- function(...) .DeadEnd()
'.rgdal_prepare_con' <- function(...) .DeadEnd()
'.rgdal_showWKT' <- function(...) .DeadEnd()
'.rgdal_writeOGR' <- function(...) .DeadEnd()
'.rgdal_readOGR' <- function(...) .DeadEnd()
'.rgdal_ogrListLayers' <- function(...) .DeadEnd()
'.rgdal_ogrInfo' <- function(...) .DeadEnd()
'.rgdal_CRSargs' <- function(...) .DeadEnd()
'.rgdal_project' <- function(...) .DeadEnd()
'.rgdal_showP4' <- function(...) .DeadEnd()
'.rgdal_requireNamespace' <- function(...) .DeadEnd()
'.rgdal_loadedNamespaces' <- function(...) .DeadEnd()
'.rgeos_requireNamespace' <- function(...) .DeadEnd()
'.rgeos_readWKT' <- function(...) .DeadEnd()
'.rgeos_gLength' <- function(...) .DeadEnd()
'.rgeos_gIntersection' <- function(...) .DeadEnd()
'.rgeos_gDifference' <- function(...) .DeadEnd()
'.rgeos_gSymdifference' <- function(...) .DeadEnd()
'.rgeos_gBuffer' <- function(...) .DeadEnd()
'.rgeos_gUnaryUnion' <- function(...) .DeadEnd()
'.rgeos_gUnion' <- function(...) .DeadEnd()
'.rgeos_gSimplify' <- function(...) .DeadEnd()
'.rgeos_gIsValid' <- function(...) .DeadEnd()

==> ursa_3.11.4.tar.gz: ursa/R/yyy.RogerBivand.R <==
'.DeadEnd' <- function() stop("Dead End after {rgdal}/{rgeos}/{maptools} retiring")
'.Retired' <- function() stop("This function is retired")
'.Missing' <- function(p) {
   stop(paste0("Required package ",ifelse(missing(p),"",dQuote(p))," is missing"))
}
'.open_rgdal' <- function(...) .DeadEnd()
'.rgdal_getRasterData' <- function(...) .DeadEnd()
'.rgdal_putRasterData' <- function(...) .DeadEnd()
'.shp.read' <- function(...) .DeadEnd()
'.shp.write' <- function(...) .DeadEnd()
'.rgdal_close_Transient' <- function(...) .DeadEnd()
'.rgdal_close_ReadOnly' <- function(...) .DeadEnd()
'.read_gdal' <- function(...) .DeadEnd()
'.rgdal_prepare_con' <- function(...) .DeadEnd()
'.rgdal_showWKT' <- function(...) .DeadEnd()
'.rgdal_writeOGR' <- function(...) .DeadEnd()
'.rgdal_readOGR' <- function(...) .DeadEnd()
'.rgdal_ogrListLayers' <- function(...) .DeadEnd()
'.rgdal_ogrInfo' <- function(...) .DeadEnd()
'.rgdal_CRSargs' <- function(...) .DeadEnd()
'.rgdal_project' <- function(...) .DeadEnd()
'.rgdal_showP4' <- function(...) .DeadEnd()
'.rgdal_requireNamespace' <- function(...) .DeadEnd()
'.rgdal_loadedNamespaces' <- function(...) .DeadEnd()
'.rgeos_requireNamespace' <- function(...) .DeadEnd()
'.rgeos_readWKT' <- function(...) .DeadEnd()
'.rgeos_gLength' <- function(...) .DeadEnd()
'.rgeos_gIntersection' <- function(...) .DeadEnd()
'.rgeos_gDifference' <- function(...) .DeadEnd()
'.rgeos_gSymdifference' <- function(...) .DeadEnd()
'.rgeos_gBuffer' <- function(...) .DeadEnd()
'.rgeos_gUnaryUnion' <- function(...) .DeadEnd()
'.rgeos_gUnion' <- function(...) .DeadEnd()
'.rgeos_gSimplify' <- function(...) .DeadEnd()
'.rgeos_gIsValid' <- function(...) .DeadEnd()
